VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
  Persistable = 0  'NotPersistable
  DataBindingBehavior = 0  'vbNone
  DataSourceBehavior  = 0  'vbNone
  MTSTransactionMode  = 0  'NotAnMTSObject
END
Attribute VB_Name = "ContextMenu"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = False
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = True
Attribute VB_Description = "Item Context Menu"
'*********************************************************************************************
'
' Shell Namespace sample
'
' Context menu handler
'
'*********************************************************************************************
'
' Author: Eduardo A. Morcillo
' E-Mail: e_morcillo@yahoo.com
' Web Page: http://www.domaindlx.com/e_morcillo
'
' Distribution: You can freely use this code in your own applications but you
'               can't publish this code in a web site, online service, or any
'               other media, without my express permission.
'
' Usage: at your own risk.
'
' Tested with:
'              Windows Me/XP
'              VB6
'              IE 6
'
' Dependencies: olelib.TLB
'
' History:
'          04/03/2000 - The file was released
'
'*********************************************************************************************
Option Explicit

' Implement the IContextMenu interface
Implements IContextMenu

' UDT for store menu tItem info
Private Type MenuItem
    Caption As String
    HelpStr As String
    Verb As String
    Default As Boolean
    Checked As Boolean
End Type

' Menu items
Dim m_Items() As MenuItem

' Selected files
Dim sFiles() As String
'
' AddFile
'
' Adds a file to the selected files array
'
Friend Sub AddFile(ByVal sFileName As String)
Dim lIdx As Long

   On Error GoTo InitializeArray

   ' Get next index
   lIdx = UBound(sFiles) + 1
   
   ReDim sFiles(0 To lIdx)
   
   sFiles(lIdx) = sFileName
   
   Exit Sub
   
InitializeArray:

   lIdx = 0
   
   Resume Next
   
End Sub '
' QueryContextMenu
'
' Inserts the menu items on the menu
'
Friend Function QueryContextMenu(ByVal hMenu As Long, ByVal indexMenu As Long, ByVal idCmdFirst As Long, ByVal idCmdLast As Long, ByVal uFlags As Long) As Long
Dim lIdx As Long
Dim MII As MENUITEMINFO

   ' Initialize the menu items array
   pvSetMenuItems
   
   ' Insert the menu items
   InsertMenu hMenu, 0, MF_BYPOSITION Or MF_SEPARATOR, 0, vbNullString
   
   For lIdx = UBound(m_Items) To 0 Step -1
   
      ' Insert the menu
      InsertMenu hMenu, 0, MF_BYPOSITION, idCmdFirst + lIdx, m_Items(lIdx).Caption
      
      If m_Items(lIdx).Checked Then CheckMenuItem hMenu, idCmdFirst + lIdx, MF_CHECKED
      
      ' Set the default menu tItem.
      ' Windows Explorer search for
      ' the default tItem when
      ' an tItem is selected from
      ' a deskband or start menu
      ' tItem.
      If m_Items(lIdx).Default Then SetMenuDefaultItem hMenu, idCmdFirst, False
   
   Next
   
     
   ' Return how many non-separator
   ' menu items we were added
   QueryContextMenu = UBound(m_Items) + 1
    
End Function

Private Sub pvSetMenuItems()
  
   ' Initialize menu items array
   ReDim m_Items(0 To 1)

   With m_Items(0)
      .Caption = "&Open project"
      .HelpStr = "Opens the project in Visual Basic."
      .Verb = "open"
      .Default = True
   End With

   With m_Items(1)
       .Caption = "&Open project folder"
       .HelpStr = "Opens the project folder."
       .Verb = "folder"
       .Default = False
   End With

End Sub

'
' GetCommandString
'
' Retrieves the language-independent command
' string or the help text for a context
' menu tItem
'
Private Sub IContextMenu_GetCommandString(ByVal idCmd As Long, ByVal uType As olelib.GetCommandStringFlags, pwReserved As Long, ByVal pszName As Long, ByVal cchMax As Long)
    
   On Error Resume Next
   
   Select Case uType
       
       Case GCS_HELPTEXT
           lstrcpynA pszName, m_Items(idCmd).HelpStr, cchMax
     
       Case GCS_HELPTEXT Or GCS_UNICODE
           Dim Unicode() As Byte
           
           Unicode = m_Items(idCmd).HelpStr & vbNullChar
           MoveMemory ByVal pszName, Unicode(0), IIf(cchMax > UBound(Unicode) + 1, UBound(Unicode) + 1, cchMax)
           
       Case GCS_VERB
           lstrcpynA pszName, m_Items(idCmd).Verb, cchMax
   
       Case Else
           lstrcpynA pszName, vbNullChar, cchMax
           
   End Select

End Sub

'
' InvokeCommand
'
' Carries out the command associated with
' a context menu tItem.
'
Private Sub IContextMenu_InvokeCommand(lpici As olelib.CMINVOKECOMMANDINFO)
Dim Idx As Long, Verb As String, Total As Currency

   On Error Resume Next
   
   ' Check if lpVerb is an string pointer
   ' or the ID
   
   If (lpici.lpVerb \ &H10000) <> 0 Then
   
      ' lpVerb is a string so
      ' copy it from the pointer
      Verb = StrFromPtr(lpici.lpVerb)
      
      ' Search the items array for
      ' the command and convert
      ' it to the tItem index
      For Idx = 0 To UBound(m_Items)
         If m_Items(Idx).Verb = Verb Then
            Exit For
         End If
      Next
   
   Else
      Idx = lpici.lpVerb
   End If
   
   ' Do the action asociated
   ' with the menu tItem
     
   Select Case Idx

      Case 0 ' Open Project
       
         For Idx = 0 To UBound(sFiles)
            ShellExecute 0, "open", sFiles(Idx), vbNullString, vbNullString, SW_SHOW
         Next
      
      Case 1 ' Open Folder
       
         For Idx = 0 To UBound(sFiles)
            ShellExecute 0, "open", GetFolder(sFiles(Idx)), vbNullString, vbNullString, SW_SHOW
         Next
       
   End Select

End Sub
Private Sub IContextMenu_QueryContextMenu(ByVal hMenu As Long, ByVal indexMenu As Long, ByVal idCmdFirst As Long, ByVal idCmdLast As Long, ByVal uFlags As olelib.QueryContextMenuFlags)

    ' QueryContextMenu cannot be implemented
    ' this way. So we use ReplaceVTableEntry
    ' to use QueryContextMenu in mdlFunctions.

End Sub

Private Sub Class_Initialize()
Dim ICM As IContextMenu
    
   ' Replace QueryContextMenu entry
   Set ICM = Me
   ReplaceVTableEntry ObjPtr(ICM), 4, AddressOf mdlReplacedEntries.IContextMenu_QueryContextMenu
   Set ICM = Nothing
   
End Sub


